############################################
#
# Split layers by field.
# Developed by James Stott @ Nicholas Pearson Associates
# www.npaconsult.co.uk
# 21/08/2012
# Based on the code of the Split Shapefile plugin.
#
###############################################


# -*- coding: utf-8 -*-
from PyQt4.QtCore import *
from PyQt4.QtGui import *

from qgis.core import *
from qgis.gui import *

import os
from __init__ import mVersion
import resources
import layers_by_field_dialog
import inspect
from os import path

class layers_by_field( object ):

  def __init__( self, iface ):
    self.iface = iface
    self.iface = iface
    
    self.dlg = layers_by_field_dialog.layers_by_field_dialog(self.iface)
    try:
      self.QgisVersion = unicode( QGis.QGIS_VERSION_INT )
    except:
      self.QgisVersion = unicode( QGis.qgisVersion )[ 0 ]

    # For i18n support
    userPluginPath = QFileInfo( QgsApplication.qgisUserDbFilePath() ).path() + "/python/plugins/layers_by_field"
    systemPluginPath = QgsApplication.prefixPath() + "/python/plugins/layers_by_field"

    overrideLocale = QSettings().value( "locale/overrideFlag", QVariant( False ) ).toBool()
    if not overrideLocale:
      localeFullName = QLocale.system().name()
    else:
      localeFullName = QSettings().value( "locale/userLocale", QVariant( "" ) ).toString()

    if QFileInfo( userPluginPath ).exists():
      translationPath = userPluginPath + "/i18n/shpsplitter_" + localeFullName + ".qm"
    else:
      translationPath = systemPluginPath + "/i18n/shpsplitter_" + localeFullName + ".qm"

    self.localePath = translationPath
    if QFileInfo( self.localePath ).exists():
      self.translator = QTranslator()
      self.translator.load( self.localePath )
      QCoreApplication.installTranslator( self.translator )

  def initGui(self):
    if int( self.QgisVersion ) < 1:
      QMessageBox.warning( self.iface.mainWindow(), "Split Layers By Field",
                           QCoreApplication.translate( "Split Layers By Field", "Quantum GIS version detected: " ) + unicode( self.QgisVersion ) + ".xx\n" +
                           QCoreApplication.translate( "Split Layers By Field", "This version of Layers From Field requires at least QGIS version 1.5.0\nPlugin will not be enabled." ) )
      return None

    self.actionRun = QAction(QIcon(":/plugins/layers_by_field/icon.png"), "Split Layers By Field", self.iface.mainWindow())
    self.actionRun.setStatusTip("Split Layers By Field adds a layer for each unique value in a text field")
    self.actionRun.setWhatsThis( "Split Layers By Field" )
    self.actionAbout = QAction(QIcon(":/plugins/layers_by_field/help.png"), \
                              "Help", self.iface.mainWindow())
    self.actionAbout.setWhatsThis("Split Layers By Field Help")

    QObject.connect(self.actionRun, SIGNAL("triggered()"), self.run)
    QObject.connect( self.actionAbout, SIGNAL( "triggered()" ), self.about )

    if hasattr( self.iface, "addPluginToVectorMenu" ):
      self.iface.addPluginToVectorMenu("Split Layers By Field", self.actionRun)
      self.iface.addPluginToVectorMenu( "Split Layers By Field", self.actionAbout )
    else:
      self.iface.addPluginToMenu("Split Layers By Field", self.actionRun)
      self.iface.addPluginToMenu( "Split Layers By Field", self.actionAbout )

  def unload(self):
    if hasattr( self.iface, "addPluginToVectorMenu" ):
      self.iface.removePluginVectorMenu("Split Layers By Field",self.actionRun)
      self.iface.removePluginVectorMenu( "Split Layers By Field", self.actionAbout )
    else:
      self.iface.removePluginMenu("Split Layers By Field",self.actionRun)
      self.iface.removePluginMenu( "Split Layers By Field", self.actionAbout )

  def about( self ):
      
    file = inspect.getsourcefile(layers_by_field)
    file = 'file://' + path.join(path.dirname(file),'help/index.html')
    file = file.replace("\\","/")
    self.iface.openURL(file, False)

    #btnClose = QPushButton( QApplication.translate( "Layers From Field", "Close" ) )
    #lines.addWidget( btnClose )
    #QObject.connect( btnClose, SIGNAL( "clicked()" ), dlgAbout, SLOT( "close()" ) )

    #dlgAbout.exec_()

  def run(self):
    
    if QgsMapLayerRegistry.instance().count() >= 1:

        self.dlg.manageGui()
        self.dlg.show()
        result = self.dlg.exec_()
        if result ==1:
            pass
    else:
        QMessageBox.information( self.iface.mainWindow(),"Info", "There are no layers loaded")
        
    
